@@ -57,8 +57,8 @@ test_that("setup_rank_data works with rankings", {
 
 test_that("setup_rank_data works for preferences", {
   expect_error(
-    setup_rank_data(preferences = beach_preferences, random = TRUE),
-    "Number of items exceeds the limit"
+    setup_rank_data(preferences = beach_preferences, max_topological_sorts = -1),
+    "max_topological_sorts must be a strictly positive number of length one"
   )
 
   rr <- matrix(rep(1:3, 2), byrow = TRUE, ncol = 3)
@@ -80,14 +80,10 @@ test_that("setup_rank_data works for preferences", {
 
   set.seed(1)
   prefdat <- subset(beach_preferences, assessor <= 3)
-  dat <- setup_rank_data(
-    preferences = prefdat, shuffle_unranked = TRUE
-  )
+  dat <- setup_rank_data(preferences = prefdat)
   expect_equal(dim(dat$rankings), c(3, 15))
   expect_equal(sum(is.na(dat$rankings)), 0)
-  dat2 <- setup_rank_data(
-    preferences = prefdat, shuffle_unranked = TRUE
-  )
+  dat2 <- setup_rank_data(preferences = prefdat)
   expect_false(
     all(dat2$rankings == dat$rankings)
   )
@@ -98,15 +94,10 @@ test_that("setup_rank_data works for preferences", {
     bottom_item <= 3 & top_item <= 3
   )
 
-  dat1 <- setup_rank_data(preferences = prefdat, random = TRUE)
-  expect_error(
-    setup_rank_data(preferences = prefdat, random = TRUE, random_limit = 1),
-    "Number of items exceeds"
-  )
-  dat2 <- setup_rank_data(
-    preferences = prefdat, random = TRUE,
-    shuffle_unranked = TRUE
+  dat1 <- setup_rank_data(
+    preferences = prefdat, max_topological_sorts = 20, n_items = 3
   )
+  dat2 <- setup_rank_data(preferences = prefdat, max_topological_sorts = 1, n_items = 3)
 
   expect_false(all(dat1$rankings == dat2$rankings))
   expect_equal(dim(dat1$rankings), dim(dat2$rankings))
